@@ -30,7 +30,6 @@ from pathlib import Path
 import ctypes
 
 _logger = logging.getLogger(__name__)
-logging.basicConfig(level=logging.DEBUG)
 
 
 def _check_fform(fform):
@@ -117,6 +116,7 @@ def _fixed_autowrap(energy_expr, prefix, save_filename=None):
     )
     c_code = '#include <complex.h>\n'
     c_code += bad_c_code
+    c_code = c_code.replace('conjugate', 'conj')
 
     write_directory = Path(tempfile.mkdtemp()).absolute()
 
@@ -175,6 +175,8 @@ double autofunc(double *xs){
 
 }
 """ % ('+'.join(['expr'+str(i)+'(xs)' for i in range(len(energy_expr_list))]))
+    c_code = c_code.replace('conjugate', 'conj')
+
     h_code = h_code.replace('\n#endif', """double autofunc(double *xs);
 
 #endif
@@ -196,8 +198,8 @@ double autofunc(double *xs){
 
     start = time.time()
     _logger.debug('Start compiling code.')
-    os.system(f'gcc -c -lm {c_path} -o {o_path}')
-    os.system(f'gcc -shared {o_path} -o {so_path}')
+    os.system(f'gcc -c -lm -fPIC {c_path} -o {o_path}')
+    os.system(f'gcc -shared -fPIC {o_path} -o {so_path}')
     _logger.debug(f'Compiling code took {time.time()-start} seconds.')
 
     if save_filename is not None:
